LCD display, Teraterm display

Dependencies:   ID12RFID ID12RFID_HelloWorld TextLCD mbed

Fork of ID12RFID_HelloWorld by Simon Ford

Revision:
1:2c017f3d2d04
Parent:
0:df71eb8a3c0b
Child:
2:53965de58fda
--- a/main.cpp	Thu Jun 03 13:25:00 2010 +0000
+++ b/main.cpp	Tue Nov 23 17:17:56 2010 +0000
@@ -1,11 +1,12 @@
 // Print RFID tag numbers
 
 #include "mbed.h"
 #include "ID12RFID.h"
 
-ID12RFID rfid(p10); // uart rx
+ID12RFID rfid(p14); // uart rx
 
 int main() {
+    printf("Hello World\n");
     while(1) {
         if(rfid.readable()) {
             printf("RFID Tag number : %d\n", rfid.read());
@@ -1,11 +1,12 @@
-// Print RFID tag numbers
+// Hello World for printing RFID tag numbers
 
 #include "mbed.h"